@@ -1,8 +1,10 @@
 package GeoIP2;
-# git description: v2.001001-3-g281552f
-$GeoIP2::VERSION = '2.001002';
 
 use 5.008;
+use strict;
+use warnings;
+
+our $VERSION = '2.001003';
 
 1;
 
@@ -18,7 +20,7 @@ GeoIP2 - Perl API for MaxMind's GeoIP2 web services and databases
 
 =head1 VERSION
 
-version 2.001002
+version 2.001003
 
 =head1 DESCRIPTION
 
@@ -122,7 +124,7 @@ Graham Knop <haarg@haarg.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
