@@ -1,8 +1,10 @@
 package GeoIP2::Model::AnonymousIP;
-$GeoIP2::Model::AnonymousIP::VERSION = '2.001002';
+
 use strict;
 use warnings;
 
+our $VERSION = '2.001003';
+
 use GeoIP2::Types qw( Bool );
 
 use Moo;
@@ -35,7 +37,7 @@ GeoIP2::Model::AnonymousIP - Model class for the GeoIP2 Anonymous IP database
 
 =head1 VERSION
 
-version 2.001002
+version 2.001003
 
 =head1 SYNOPSIS
 
@@ -51,7 +53,7 @@ version 2.001002
       }
   );
 
-  say $anon->is_anonymous();
+  print $anon->is_anonymous(), "\n";
 
 =head1 DESCRIPTION
 
@@ -106,7 +108,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
