@@ -1,8 +1,10 @@
 package GeoIP2::Model::City;
-$GeoIP2::Model::City::VERSION = '2.001002';
+
 use strict;
 use warnings;
 
+our $VERSION = '2.001003';
+
 use GeoIP2::Types qw( HashRef object_isa_type );
 use Sub::Quote qw( quote_sub );
 
@@ -26,7 +28,7 @@ GeoIP2::Model::City - Model class for GeoIP2 Precision: City and GeoIP2 City
 
 =head1 VERSION
 
-version 2.001002
+version 2.001003
 
 =head1 SYNOPSIS
 
@@ -42,7 +44,7 @@ version 2.001002
   my $city = $client->city( ip => '24.24.24.24' );
 
   my $city_rec = $city->city();
-  say $city_rec->name();
+  print $city_rec->name(), "\n";
 
 =head1 DESCRIPTION
 
@@ -104,7 +106,7 @@ from the C<country> for things like military bases.
 
 =head2 $city->subdivisions()
 
-Returns an array of L<GeoIP2::Record::Subdvision> objects representing the
+Returns an array of L<GeoIP2::Record::Subdivision> objects representing the
 country subdivisions for the requested IP address. The number and type of
 subdivisions varies by country, but a subdivision is typically a state,
 province, county, etc.
@@ -150,7 +152,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
