@@ -1,8 +1,10 @@
 package GeoIP2::Model::Country;
-$GeoIP2::Model::Country::VERSION = '2.001002';
+
 use strict;
 use warnings;
 
+our $VERSION = '2.001003';
+
 use GeoIP2::Types qw( HashRef object_isa_type );
 use Sub::Quote qw( quote_sub );
 
@@ -27,7 +29,7 @@ GeoIP2::Model::Country - Model class for the GeoIP2 Precision: Country and GeoIP
 
 =head1 VERSION
 
-version 2.001002
+version 2.001003
 
 =head1 SYNOPSIS
 
@@ -43,7 +45,7 @@ version 2.001002
   my $country = $client->country( ip => '24.24.24.24' );
 
   my $country_rec = $country->country();
-  say $country_rec->iso_code();
+  print $country_rec->iso_code(), "\n";
 
 =head1 DESCRIPTION
 
@@ -109,7 +111,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
