@@ -1,8 +1,10 @@
 package GeoIP2::Model::Domain;
-$GeoIP2::Model::Domain::VERSION = '2.001002';
+
 use strict;
 use warnings;
 
+our $VERSION = '2.001003';
+
 use GeoIP2::Types qw( IPAddress Str );
 
 use Moo;
@@ -29,7 +31,7 @@ GeoIP2::Model::Domain - Model class for the GeoIP2 Domain database
 
 =head1 VERSION
 
-version 2.001002
+version 2.001003
 
 =head1 SYNOPSIS
 
@@ -41,7 +43,7 @@ version 2.001002
       raw  => { domain => 'maxmind.com', ip_address => '24.24.24.24'}
   );
 
-  say $domain->domain();
+  print $domain->domain(), "\n";
 
 =head1 DESCRIPTION
 
@@ -80,7 +82,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
