@@ -1,8 +1,10 @@
 package GeoIP2::Model::ISP;
-$GeoIP2::Model::ISP::VERSION = '2.001002';
+
 use strict;
 use warnings;
 
+our $VERSION = '2.001003';
+
 use GeoIP2::Types qw( IPAddress NonNegativeInt Str );
 
 use Moo;
@@ -47,7 +49,7 @@ GeoIP2::Model::ISP - Model class for the GeoIP2 ISP database
 
 =head1 VERSION
 
-version 2.001002
+version 2.001003
 
 =head1 SYNOPSIS
 
@@ -65,10 +67,10 @@ version 2.001002
       }
   );
 
-  say $isp->autonomous_system_number();
-  say $isp->autonomous_system_organization();
-  say $isp->isp();
-  say $isp->organization();
+  print $isp->autonomous_system_number(), "\n";
+  print $isp->autonomous_system_organization(), "\n";
+  print $isp->isp(), "\n";
+  print $isp->organization(), "\n";
 
 =head1 DESCRIPTION
 
@@ -122,7 +124,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
