@@ -1,8 +1,10 @@
 package GeoIP2::Record::Country;
-$GeoIP2::Record::Country::VERSION = '2.001002';
+
 use strict;
 use warnings;
 
+our $VERSION = '2.001003';
+
 use Moo;
 
 with 'GeoIP2::Role::Record::Country';
@@ -21,7 +23,7 @@ GeoIP2::Record::Country - Contains data for the country record associated with a
 
 =head1 VERSION
 
-version 2.001002
+version 2.001003
 
 =head1 SYNOPSIS
 
@@ -37,7 +39,7 @@ version 2.001002
   my $insights = $client->insights( ip => '24.24.24.24' );
 
   my $country_rec = $insights->country();
-  say $country_rec->name();
+  print $country_rec->name(), "\n";
 
 =head1 DESCRIPTION
 
@@ -109,7 +111,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
