@@ -1,8 +1,10 @@
 package GeoIP2::Record::Location;
-$GeoIP2::Record::Location::VERSION = '2.001002';
+
 use strict;
 use warnings;
 
+our $VERSION = '2.001003';
+
 use GeoIP2::Types qw( NonNegativeInt Num PositiveInt Str );
 
 use Moo;
@@ -51,7 +53,7 @@ GeoIP2::Record::Location - Contains data for the location record associated with
 
 =head1 VERSION
 
-version 2.001002
+version 2.001003
 
 =head1 SYNOPSIS
 
@@ -67,7 +69,7 @@ version 2.001002
   my $insights = $client->insights( ip => '24.24.24.24' );
 
   my $location_rec = $insights->location();
-  say $location_rec->name();
+  print $location_rec->name(), "\n";
 
 =head1 DESCRIPTION
 
@@ -133,7 +135,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
