@@ -1,8 +1,10 @@
 package GeoIP2::Record::MaxMind;
-$GeoIP2::Record::MaxMind::VERSION = '2.001002';
+
 use strict;
 use warnings;
 
+our $VERSION = '2.001003';
+
 use GeoIP2::Types qw( NonNegativeInt );
 
 use Moo;
@@ -26,7 +28,7 @@ GeoIP2::Record::MaxMind - Contains data for the maxmind record returned from a w
 
 =head1 VERSION
 
-version 2.001002
+version 2.001003
 
 =head1 SYNOPSIS
 
@@ -42,7 +44,7 @@ version 2.001002
   my $insights = $client->insights( ip => '24.24.24.24' );
 
   my $maxmind_rec = $insights->maxmind();
-  say $maxmind_rec->queries_remaining();
+  print $maxmind_rec->queries_remaining(), "\n";
 
 =head1 DESCRIPTION
 
@@ -83,7 +85,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
