@@ -1,8 +1,10 @@
 package GeoIP2::Record::Postal;
-$GeoIP2::Record::Postal::VERSION = '2.001002';
+
 use strict;
 use warnings;
 
+our $VERSION = '2.001003';
+
 use GeoIP2::Types qw( NonNegativeInt Str );
 
 use Moo;
@@ -33,7 +35,7 @@ GeoIP2::Record::Postal - Contains data for the postal code record associated wit
 
 =head1 VERSION
 
-version 2.001002
+version 2.001003
 
 =head1 SYNOPSIS
 
@@ -49,7 +51,7 @@ version 2.001002
   my $insights = $client->insights( ip => '24.24.24.24' );
 
   my $postal_rec = $insights->postal();
-  say $postal_rec->code();
+  print $postal_rec->code(), "\n";
 
 =head1 DESCRIPTION
 
@@ -96,7 +98,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
