@@ -1,8 +1,10 @@
 package GeoIP2::Record::RepresentedCountry;
-$GeoIP2::Record::RepresentedCountry::VERSION = '2.001002';
+
 use strict;
 use warnings;
 
+our $VERSION = '2.001003';
+
 use GeoIP2::Types qw( Str );
 
 use Moo;
@@ -29,7 +31,7 @@ GeoIP2::Record::RepresentedCountry - Contains data for the represented country r
 
 =head1 VERSION
 
-version 2.001002
+version 2.001003
 
 =head1 SYNOPSIS
 
@@ -45,8 +47,8 @@ version 2.001002
   my $insights = $client->insights( ip => '24.24.24.24' );
 
   my $country_rec = $insights->reprented_country();
-  say $country_rec->name();
-  say $country_rec->type();
+  print $country_rec->name(), "\n";
+  print $country_rec->type(), "\n";
 
 =head1 DESCRIPTION
 
@@ -128,7 +130,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
