@@ -1,8 +1,10 @@
 package GeoIP2::Record::Subdivision;
-$GeoIP2::Record::Subdivision::VERSION = '2.001002';
+
 use strict;
 use warnings;
 
+our $VERSION = '2.001003';
+
 use GeoIP2::Types qw( NonNegativeInt PositiveInt Str );
 
 use Moo;
@@ -41,7 +43,7 @@ GeoIP2::Record::Subdivision - Contains data for the subdivision record associate
 
 =head1 VERSION
 
-version 2.001002
+version 2.001003
 
 =head1 SYNOPSIS
 
@@ -57,7 +59,7 @@ version 2.001002
   my $insights = $client->insights( ip => '24.24.24.24' );
 
   my $subdivision_rec = $insights->subdivision();
-  say $subdivision_rec->name();
+  print $subdivision_rec->name(), "\n";
 
 =head1 DESCRIPTION
 
@@ -131,7 +133,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
