@@ -1,8 +1,10 @@
 package GeoIP2::Record::Traits;
-$GeoIP2::Record::Traits::VERSION = '2.001002';
+
 use strict;
 use warnings;
 
+our $VERSION = '2.001003';
+
 use GeoIP2::Types qw( Bool BoolCoercion IPAddress NonNegativeInt Str );
 use Sub::Quote qw( quote_sub );
 
@@ -74,7 +76,7 @@ GeoIP2::Record::Traits - Contains data for the traits record associated with an
 
 =head1 VERSION
 
-version 2.001002
+version 2.001003
 
 =head1 SYNOPSIS
 
@@ -90,7 +92,7 @@ version 2.001002
   my $insights = $client->insights( ip => '24.24.24.24' );
 
   my $traits_rec = $insights->country();
-  say $traits_rec->name();
+  print $traits_rec->name(), "\n";
 
 =head1 DESCRIPTION
 
@@ -226,7 +228,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
