@@ -1,10 +1,12 @@
 package GeoIP2::WebService::Client;
-$GeoIP2::WebService::Client::VERSION = '2.001002';
+
 use 5.008;
 
 use strict;
 use warnings;
 
+our $VERSION = '2.001003';
+
 use Data::Validate::IP 0.19 qw( is_public_ipv4 is_public_ipv6 );
 use GeoIP2::Error::Generic;
 use GeoIP2::Error::HTTP;
@@ -15,6 +17,8 @@ use GeoIP2::Model::Country;
 use GeoIP2::Model::Insights;
 use GeoIP2::Types
     qw( JSONObject MaxMindID MaxMindLicenseKey Str URIObject UserAgentObject );
+use HTTP::Headers;
+use HTTP::Request;
 use JSON;
 use MIME::Base64 qw( encode_base64 );
 use LWP::Protocol::https;
@@ -70,11 +74,10 @@ has _json => (
 sub BUILD {
     my $self = shift;
 
-    local $@;
-    my $self_version = eval { 'v' . $self->VERSION() } || 'v?';
+    my $self_version = try { 'v' . $self->VERSION() } || 'v?';
 
     my $ua = $self->ua();
-    my $ua_version = eval { 'v' . $ua->VERSION() } || 'v?';
+    my $ua_version = try { 'v' . $ua->VERSION() } || 'v?';
 
     my $agent
         = blessed($self)
@@ -312,7 +315,7 @@ GeoIP2::WebService::Client - Perl API for the GeoIP2 Precision web services
 
 =head1 VERSION
 
-version 2.001002
+version 2.001003
 
 =head1 SYNOPSIS
 
@@ -333,7 +336,7 @@ version 2.001002
   my $insights = $client->insights( ip => '24.24.24.24' );
 
   my $country = $insights->country();
-  say $country->iso_code();
+  print $country->iso_code(), "\n";
 
 =head1 DESCRIPTION
 
@@ -559,7 +562,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
